@@ -6,7 +6,7 @@ use WebService::Lob;
 
 memoize 'lob';
 sub lob {
-    my $api_key = $ENV{LOB_API_KEY};
+    my $api_key = 'test_f126eb04f7a10e05de646d4094b42c96ab6';
     WebService::Lob->new(api_key => $api_key) if $api_key;
 }
 
